summaryrefslogtreecommitdiff
path: root/lib/url.c
diff options
context:
space:
mode:
Diffstat (limited to 'lib/url.c')
-rw-r--r--lib/url.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/url.c b/lib/url.c
index 77117b881..ee6285c60 100644
--- a/lib/url.c
+++ b/lib/url.c
@@ -1176,9 +1176,9 @@ ConnectionExists(struct Curl_easy *data,
}
if(Curl_resolver_asynch()) {
/* ip_addr_str[0] is NUL only if the resolving of the name hasn't
completed yet and until then we don't re-use this connection */
- if(!check->ip_addr_str[0]) {
+ if(!check->primary_ip[0]) {
infof(data,
"Connection #%ld is still name resolving, can't reuse\n",
check->connection_id);
@@ -1491,7 +1491,7 @@ void Curl_verboseconnect(struct Curl_easy *data,
#endif
conn->bits.conn_to_host ? conn->conn_to_host.dispname :
conn->host.dispname,
- conn->ip_addr_str, conn->port, conn->connection_id);
+ conn->primary_ip, conn->port, conn->connection_id);
}
#endif
@@ -1176,9 +1176,9 @@ ConnectionExists(struct Curl_easy *data,
}
if(Curl_resolver_asynch()) {
- /* ip_addr_str[0] is NUL only if the resolving of the name hasn't
+ /* primary_ip[0] is NUL only if the resolving of the name hasn't
completed yet and until then we don't re-use this connection */